import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import {
} from 'react-admin';
import { Drawer, Box, Typography, Card, IconButton, Stack } from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import * as Common from '@/utils/common';
import { PAGE_DRAWER_WIDTH } from '@/config/setting';

const PageDrawer = (props) => {
    const {
        title = 'Drawer',
        drawerVal,
        setDrawerVal,
        closeCallback,
        width = PAGE_DRAWER_WIDTH,
        children
    } = props;

    const handleClose = () => {
        setDrawerVal(null);
        if (closeCallback) {
            closeCallback();
        }
    }

    return (
        <Drawer
            variant="persistent"
            open={!!drawerVal}
            anchor="right"
            onClose={handleClose}
            sx={{ zIndex: 100 }}
        >
            {!!drawerVal && (
                <Box pt={5} width={{ xs: '100vW', sm: width }} height={'calc(100vh - 200px);'} mt={{ xs: 2, sm: 1 }}>
                    <Stack direction="row" p={2}>
                        <Typography variant="h6" flex="1">
                            {title}
                        </Typography>
                        <IconButton onClick={handleClose} size="small">
                            <CloseIcon />
                        </IconButton>
                    </Stack>
                    {children}
                </Box>
            )}
        </Drawer>
    )
}

export default PageDrawer;